==> SCFiler2-0.05.zip: SCFiler2/SCFiler2/MainForm.Designer.cs <==
﻿namespace SCFiler2 {
	partial class MainForm {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.menu_strip = new System.Windows.Forms.MenuStrip();
			this.tool_strip = new System.Windows.Forms.ToolStrip();
			this.status_strip = new System.Windows.Forms.StatusStrip();
			this.Level1_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level2_Main_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_Listview_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_History1_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_History2_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.drive_toolbar = new System.Windows.Forms.ToolStrip();
			this.left_file_listview = new SCFiler2.FileView();
			this.right_file_listview = new SCFiler2.FileView();
			this.ファイルFToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.フォルダDToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.ツールTToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.設定OToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.menu_strip.SuspendLayout();
			this.Level1_SplitContainer.Panel1.SuspendLayout();
			this.Level1_SplitContainer.Panel2.SuspendLayout();
			this.Level1_SplitContainer.SuspendLayout();
			this.Level2_Main_SplitContainer.Panel1.SuspendLayout();
			this.Level2_Main_SplitContainer.SuspendLayout();
			this.Level3_Listview_SplitContainer.Panel1.SuspendLayout();
			this.Level3_Listview_SplitContainer.Panel2.SuspendLayout();
			this.Level3_Listview_SplitContainer.SuspendLayout();
			this.Level3_History1_SplitContainer.Panel2.SuspendLayout();
			this.Level3_History1_SplitContainer.SuspendLayout();
			this.Level3_History2_SplitContainer.SuspendLayout();
			this.SuspendLayout();
			// 
			// menu_strip
			// 
			this.menu_strip.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.ファイルFToolStripMenuItem,
            this.フォルダDToolStripMenuItem,
            this.ツールTToolStripMenuItem});
			this.menu_strip.Location = new System.Drawing.Point(0, 0);
			this.menu_strip.Name = "menu_strip";
			this.menu_strip.Size = new System.Drawing.Size(503, 26);
			this.menu_strip.TabIndex = 0;
			this.menu_strip.Text = "menuStrip1";
			// 
			// tool_strip
			// 
			this.tool_strip.Location = new System.Drawing.Point(0, 26);
			this.tool_strip.Name = "tool_strip";
			this.tool_strip.Size = new System.Drawing.Size(503, 25);
			this.tool_strip.TabIndex = 1;
			this.tool_strip.Text = "toolStrip1";
			// 
			// status_strip
			// 
			this.status_strip.Location = new System.Drawing.Point(0, 317);
			this.status_strip.Name = "status_strip";
			this.status_strip.Size = new System.Drawing.Size(503, 22);
			this.status_strip.TabIndex = 2;
			this.status_strip.Text = "statusStrip1";
			// 
			// Level1_SplitContainer
			// 
			this.Level1_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level1_SplitContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel2;
			this.Level1_SplitContainer.Location = new System.Drawing.Point(0, 76);
			this.Level1_SplitContainer.Name = "Level1_SplitContainer";
			// 
			// Level1_SplitContainer.Panel1
			// 
			this.Level1_SplitContainer.Panel1.Controls.Add(this.Level2_Main_SplitContainer);
			// 
			// Level1_SplitContainer.Panel2
			// 
			this.Level1_SplitContainer.Panel2.Controls.Add(this.Level3_History1_SplitContainer);
			this.Level1_SplitContainer.Size = new System.Drawing.Size(503, 241);
			this.Level1_SplitContainer.SplitterDistance = 395;
			this.Level1_SplitContainer.TabIndex = 3;
			// 
			// Level2_Main_SplitContainer
			// 
			this.Level2_Main_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level2_Main_SplitContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel2;
			this.Level2_Main_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level2_Main_SplitContainer.Name = "Level2_Main_SplitContainer";
			this.Level2_Main_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			// 
			// Level2_Main_SplitContainer.Panel1
			// 
			this.Level2_Main_SplitContainer.Panel1.Controls.Add(this.Level3_Listview_SplitContainer);
			this.Level2_Main_SplitContainer.Size = new System.Drawing.Size(395, 241);
			this.Level2_Main_SplitContainer.SplitterDistance = 181;
			this.Level2_Main_SplitContainer.TabIndex = 0;
			// 
			// Level3_Listview_SplitContainer
			// 
			this.Level3_Listview_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_Listview_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_Listview_SplitContainer.Name = "Level3_Listview_SplitContainer";
			// 
			// Level3_Listview_SplitContainer.Panel1
			// 
			this.Level3_Listview_SplitContainer.Panel1.Controls.Add(this.left_file_listview);
			// 
			// Level3_Listview_SplitContainer.Panel2
			// 
			this.Level3_Listview_SplitContainer.Panel2.Controls.Add(this.right_file_listview);
			this.Level3_Listview_SplitContainer.Size = new System.Drawing.Size(395, 181);
			this.Level3_Listview_SplitContainer.SplitterDistance = 186;
			this.Level3_Listview_SplitContainer.TabIndex = 0;
			// 
			// Level3_History1_SplitContainer
			// 
			this.Level3_History1_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_History1_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_History1_SplitContainer.Name = "Level3_History1_SplitContainer";
			this.Level3_History1_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			// 
			// Level3_History1_SplitContainer.Panel2
			// 
			this.Level3_History1_SplitContainer.Panel2.Controls.Add(this.Level3_History2_SplitContainer);
			this.Level3_History1_SplitContainer.Size = new System.Drawing.Size(104, 241);
			this.Level3_History1_SplitContainer.SplitterDistance = 53;
			this.Level3_History1_SplitContainer.TabIndex = 0;
			// 
			// Level3_History2_SplitContainer
			// 
			this.Level3_History2_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_History2_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_History2_SplitContainer.Name = "Level3_History2_SplitContainer";
			this.Level3_History2_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			this.Level3_History2_SplitContainer.Size = new System.Drawing.Size(104, 184);
			this.Level3_History2_SplitContainer.SplitterDistance = 100;
			this.Level3_History2_SplitContainer.TabIndex = 0;
			// 
			// drive_toolbar
			// 
			this.drive_toolbar.Location = new System.Drawing.Point(0, 51);
			this.drive_toolbar.Name = "drive_toolbar";
			this.drive_toolbar.Size = new System.Drawing.Size(503, 25);
			this.drive_toolbar.TabIndex = 4;
			this.drive_toolbar.Text = "toolStrip1";
			// 
			// left_file_listview
			// 
			this.left_file_listview.Dock = System.Windows.Forms.DockStyle.Fill;
			this.left_file_listview.Location = new System.Drawing.Point(0, 0);
			this.left_file_listview.Name = "left_file_listview";
			this.left_file_listview.Size = new System.Drawing.Size(186, 181);
			this.left_file_listview.TabIndex = 0;
			// 
			// right_file_listview
			// 
			this.right_file_listview.Dock = System.Windows.Forms.DockStyle.Fill;
			this.right_file_listview.Location = new System.Drawing.Point(0, 0);
			this.right_file_listview.Name = "right_file_listview";
			this.right_file_listview.Size = new System.Drawing.Size(205, 181);
			this.right_file_listview.TabIndex = 0;
			// 
			// ファイルFToolStripMenuItem
			// 
			this.ファイルFToolStripMenuItem.Name = "ファイルFToolStripMenuItem";
			this.ファイルFToolStripMenuItem.Size = new System.Drawing.Size(85, 22);
			this.ファイルFToolStripMenuItem.Text = "ファイル(&F)";
			// 
			// フォルダDToolStripMenuItem
			// 
			this.フォルダDToolStripMenuItem.Name = "フォルダDToolStripMenuItem";
			this.フォルダDToolStripMenuItem.Size = new System.Drawing.Size(87, 22);
			this.フォルダDToolStripMenuItem.Text = "フォルダ(&D)";
			// 
			// ツールTToolStripMenuItem
			// 
			this.ツールTToolStripMenuItem.DropDownItems.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.設定OToolStripMenuItem});
			this.ツールTToolStripMenuItem.Name = "ツールTToolStripMenuItem";
			this.ツールTToolStripMenuItem.Size = new System.Drawing.Size(74, 22);
			this.ツールTToolStripMenuItem.Text = "ツール(&T)";
			// 
			// 設定OToolStripMenuItem
			// 
			this.設定OToolStripMenuItem.Name = "設定OToolStripMenuItem";
			this.設定OToolStripMenuItem.Size = new System.Drawing.Size(152, 22);
			this.設定OToolStripMenuItem.Text = "設定(&O)";
			this.設定OToolStripMenuItem.Click += new System.EventHandler(this.設定OToolStripMenuItem_Click);
			// 
			// MainForm
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(503, 339);
			this.Controls.Add(this.Level1_SplitContainer);
			this.Controls.Add(this.status_strip);
			this.Controls.Add(this.drive_toolbar);
			this.Controls.Add(this.tool_strip);
			this.Controls.Add(this.menu_strip);
			this.MainMenuStrip = this.menu_strip;
			this.Name = "MainForm";
			this.Text = "SCFiler2";
			this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.MainForm_FormClosing);
			this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.MainForm_KeyDown);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.menu_strip.ResumeLayout(false);
			this.menu_strip.PerformLayout();
			this.Level1_SplitContainer.Panel1.ResumeLayout(false);
			this.Level1_SplitContainer.Panel2.ResumeLayout(false);
			this.Level1_SplitContainer.ResumeLayout(false);
			this.Level2_Main_SplitContainer.Panel1.ResumeLayout(false);
			this.Level2_Main_SplitContainer.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.Panel1.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.Panel2.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.ResumeLayout(false);
			this.Level3_History1_SplitContainer.Panel2.ResumeLayout(false);
			this.Level3_History1_SplitContainer.ResumeLayout(false);
			this.Level3_History2_SplitContainer.ResumeLayout(false);
			this.ResumeLayout(false);
			this.PerformLayout();

		}

		#endregion

		private System.Windows.Forms.MenuStrip menu_strip;
		private System.Windows.Forms.ToolStrip tool_strip;
		private System.Windows.Forms.StatusStrip status_strip;
		private System.Windows.Forms.SplitContainer Level1_SplitContainer;
		private System.Windows.Forms.SplitContainer Level2_Main_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_Listview_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_History1_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_History2_SplitContainer;
		private FileView left_file_listview;
		private FileView right_file_listview;
		private System.Windows.Forms.ToolStrip drive_toolbar;
		private System.Windows.Forms.ToolStripMenuItem ファイルFToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem フォルダDToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem ツールTToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem 設定OToolStripMenuItem;
	}
}

==> SCFiler2-0.06.zip: SCFiler2/SCFiler2/MainForm.Designer.cs <==
﻿namespace SCFiler2 {
	partial class MainForm {
		/// <summary>
		/// 必要なデザイナ変数です。
		/// </summary>
		private System.ComponentModel.IContainer components = null;

		/// <summary>
		/// 使用中のリソースをすべてクリーンアップします。
		/// </summary>
		/// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
		protected override void Dispose(bool disposing) {
			if (disposing && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}

		#region Windows フォーム デザイナで生成されたコード

		/// <summary>
		/// デザイナ サポートに必要なメソッドです。このメソッドの内容を
		/// コード エディタで変更しないでください。
		/// </summary>
		private void InitializeComponent() {
			this.menu_strip = new System.Windows.Forms.MenuStrip();
			this.ファイルFToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.フォルダDToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.ツールTToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.設定OToolStripMenuItem = new System.Windows.Forms.ToolStripMenuItem();
			this.tool_strip = new System.Windows.Forms.ToolStrip();
			this.status_strip = new System.Windows.Forms.StatusStrip();
			this.Level1_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level2_Main_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_Listview_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_History1_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.Level3_History2_SplitContainer = new System.Windows.Forms.SplitContainer();
			this.drive_toolbar = new System.Windows.Forms.ToolStrip();
			this.left_file_listview = new SCFiler2.FileView();
			this.right_file_listview = new SCFiler2.FileView();
			this.folder_history = new SCFiler2.HistoryView();
			this.file_history1 = new SCFiler2.HistoryView();
			this.file_history2 = new SCFiler2.HistoryView();
			this.menu_strip.SuspendLayout();
			this.Level1_SplitContainer.Panel1.SuspendLayout();
			this.Level1_SplitContainer.Panel2.SuspendLayout();
			this.Level1_SplitContainer.SuspendLayout();
			this.Level2_Main_SplitContainer.Panel1.SuspendLayout();
			this.Level2_Main_SplitContainer.SuspendLayout();
			this.Level3_Listview_SplitContainer.Panel1.SuspendLayout();
			this.Level3_Listview_SplitContainer.Panel2.SuspendLayout();
			this.Level3_Listview_SplitContainer.SuspendLayout();
			this.Level3_History1_SplitContainer.Panel1.SuspendLayout();
			this.Level3_History1_SplitContainer.Panel2.SuspendLayout();
			this.Level3_History1_SplitContainer.SuspendLayout();
			this.Level3_History2_SplitContainer.Panel1.SuspendLayout();
			this.Level3_History2_SplitContainer.Panel2.SuspendLayout();
			this.Level3_History2_SplitContainer.SuspendLayout();
			this.SuspendLayout();
			// 
			// menu_strip
			// 
			this.menu_strip.Items.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.ファイルFToolStripMenuItem,
            this.フォルダDToolStripMenuItem,
            this.ツールTToolStripMenuItem});
			this.menu_strip.Location = new System.Drawing.Point(0, 0);
			this.menu_strip.Name = "menu_strip";
			this.menu_strip.Size = new System.Drawing.Size(503, 26);
			this.menu_strip.TabIndex = 0;
			this.menu_strip.Text = "menuStrip1";
			// 
			// ファイルFToolStripMenuItem
			// 
			this.ファイルFToolStripMenuItem.Name = "ファイルFToolStripMenuItem";
			this.ファイルFToolStripMenuItem.Size = new System.Drawing.Size(85, 22);
			this.ファイルFToolStripMenuItem.Text = "ファイル(&F)";
			// 
			// フォルダDToolStripMenuItem
			// 
			this.フォルダDToolStripMenuItem.Name = "フォルダDToolStripMenuItem";
			this.フォルダDToolStripMenuItem.Size = new System.Drawing.Size(87, 22);
			this.フォルダDToolStripMenuItem.Text = "フォルダ(&D)";
			// 
			// ツールTToolStripMenuItem
			// 
			this.ツールTToolStripMenuItem.DropDownItems.AddRange(new System.Windows.Forms.ToolStripItem[] {
            this.設定OToolStripMenuItem});
			this.ツールTToolStripMenuItem.Name = "ツールTToolStripMenuItem";
			this.ツールTToolStripMenuItem.Size = new System.Drawing.Size(74, 22);
			this.ツールTToolStripMenuItem.Text = "ツール(&T)";
			// 
			// 設定OToolStripMenuItem
			// 
			this.設定OToolStripMenuItem.Name = "設定OToolStripMenuItem";
			this.設定OToolStripMenuItem.Size = new System.Drawing.Size(119, 22);
			this.設定OToolStripMenuItem.Text = "設定(&O)";
			this.設定OToolStripMenuItem.Click += new System.EventHandler(this.設定OToolStripMenuItem_Click);
			// 
			// tool_strip
			// 
			this.tool_strip.Location = new System.Drawing.Point(0, 26);
			this.tool_strip.Name = "tool_strip";
			this.tool_strip.Size = new System.Drawing.Size(503, 25);
			this.tool_strip.TabIndex = 1;
			this.tool_strip.Text = "toolStrip1";
			// 
			// status_strip
			// 
			this.status_strip.Location = new System.Drawing.Point(0, 317);
			this.status_strip.Name = "status_strip";
			this.status_strip.Size = new System.Drawing.Size(503, 22);
			this.status_strip.TabIndex = 2;
			this.status_strip.Text = "statusStrip1";
			// 
			// Level1_SplitContainer
			// 
			this.Level1_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level1_SplitContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel2;
			this.Level1_SplitContainer.ForeColor = System.Drawing.SystemColors.ActiveCaptionText;
			this.Level1_SplitContainer.Location = new System.Drawing.Point(0, 76);
			this.Level1_SplitContainer.Name = "Level1_SplitContainer";
			// 
			// Level1_SplitContainer.Panel1
			// 
			this.Level1_SplitContainer.Panel1.Controls.Add(this.Level2_Main_SplitContainer);
			// 
			// Level1_SplitContainer.Panel2
			// 
			this.Level1_SplitContainer.Panel2.Controls.Add(this.Level3_History1_SplitContainer);
			this.Level1_SplitContainer.Size = new System.Drawing.Size(503, 241);
			this.Level1_SplitContainer.SplitterDistance = 395;
			this.Level1_SplitContainer.TabIndex = 3;
			// 
			// Level2_Main_SplitContainer
			// 
			this.Level2_Main_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level2_Main_SplitContainer.FixedPanel = System.Windows.Forms.FixedPanel.Panel2;
			this.Level2_Main_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level2_Main_SplitContainer.Name = "Level2_Main_SplitContainer";
			this.Level2_Main_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			// 
			// Level2_Main_SplitContainer.Panel1
			// 
			this.Level2_Main_SplitContainer.Panel1.Controls.Add(this.Level3_Listview_SplitContainer);
			this.Level2_Main_SplitContainer.Size = new System.Drawing.Size(395, 241);
			this.Level2_Main_SplitContainer.SplitterDistance = 181;
			this.Level2_Main_SplitContainer.TabIndex = 0;
			// 
			// Level3_Listview_SplitContainer
			// 
			this.Level3_Listview_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_Listview_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_Listview_SplitContainer.Name = "Level3_Listview_SplitContainer";
			// 
			// Level3_Listview_SplitContainer.Panel1
			// 
			this.Level3_Listview_SplitContainer.Panel1.Controls.Add(this.left_file_listview);
			// 
			// Level3_Listview_SplitContainer.Panel2
			// 
			this.Level3_Listview_SplitContainer.Panel2.Controls.Add(this.right_file_listview);
			this.Level3_Listview_SplitContainer.Size = new System.Drawing.Size(395, 181);
			this.Level3_Listview_SplitContainer.SplitterDistance = 186;
			this.Level3_Listview_SplitContainer.TabIndex = 0;
			// 
			// Level3_History1_SplitContainer
			// 
			this.Level3_History1_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_History1_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_History1_SplitContainer.Name = "Level3_History1_SplitContainer";
			this.Level3_History1_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			// 
			// Level3_History1_SplitContainer.Panel1
			// 
			this.Level3_History1_SplitContainer.Panel1.Controls.Add(this.folder_history);
			// 
			// Level3_History1_SplitContainer.Panel2
			// 
			this.Level3_History1_SplitContainer.Panel2.Controls.Add(this.Level3_History2_SplitContainer);
			this.Level3_History1_SplitContainer.Size = new System.Drawing.Size(104, 241);
			this.Level3_History1_SplitContainer.SplitterDistance = 53;
			this.Level3_History1_SplitContainer.TabIndex = 0;
			// 
			// Level3_History2_SplitContainer
			// 
			this.Level3_History2_SplitContainer.Dock = System.Windows.Forms.DockStyle.Fill;
			this.Level3_History2_SplitContainer.Location = new System.Drawing.Point(0, 0);
			this.Level3_History2_SplitContainer.Name = "Level3_History2_SplitContainer";
			this.Level3_History2_SplitContainer.Orientation = System.Windows.Forms.Orientation.Horizontal;
			// 
			// Level3_History2_SplitContainer.Panel1
			// 
			this.Level3_History2_SplitContainer.Panel1.Controls.Add(this.file_history1);
			// 
			// Level3_History2_SplitContainer.Panel2
			// 
			this.Level3_History2_SplitContainer.Panel2.Controls.Add(this.file_history2);
			this.Level3_History2_SplitContainer.Size = new System.Drawing.Size(104, 184);
			this.Level3_History2_SplitContainer.SplitterDistance = 100;
			this.Level3_History2_SplitContainer.TabIndex = 0;
			// 
			// drive_toolbar
			// 
			this.drive_toolbar.Location = new System.Drawing.Point(0, 51);
			this.drive_toolbar.Name = "drive_toolbar";
			this.drive_toolbar.Size = new System.Drawing.Size(503, 25);
			this.drive_toolbar.TabIndex = 4;
			this.drive_toolbar.Text = "toolStrip1";
			// 
			// left_file_listview
			// 
			this.left_file_listview.Dock = System.Windows.Forms.DockStyle.Fill;
			this.left_file_listview.Location = new System.Drawing.Point(0, 0);
			this.left_file_listview.Name = "left_file_listview";
			this.left_file_listview.Size = new System.Drawing.Size(186, 181);
			this.left_file_listview.TabIndex = 0;
			// 
			// right_file_listview
			// 
			this.right_file_listview.Dock = System.Windows.Forms.DockStyle.Fill;
			this.right_file_listview.Location = new System.Drawing.Point(0, 0);
			this.right_file_listview.Name = "right_file_listview";
			this.right_file_listview.Size = new System.Drawing.Size(205, 181);
			this.right_file_listview.TabIndex = 0;
			// 
			// folder_history
			// 
			this.folder_history.Dock = System.Windows.Forms.DockStyle.Fill;
			this.folder_history.Location = new System.Drawing.Point(0, 0);
			this.folder_history.Name = "folder_history";
			this.folder_history.Size = new System.Drawing.Size(104, 53);
			this.folder_history.TabIndex = 0;
			// 
			// file_history1
			// 
			this.file_history1.Dock = System.Windows.Forms.DockStyle.Fill;
			this.file_history1.Location = new System.Drawing.Point(0, 0);
			this.file_history1.Name = "file_history1";
			this.file_history1.Size = new System.Drawing.Size(104, 100);
			this.file_history1.TabIndex = 0;
			// 
			// file_history2
			// 
			this.file_history2.Dock = System.Windows.Forms.DockStyle.Fill;
			this.file_history2.Location = new System.Drawing.Point(0, 0);
			this.file_history2.Name = "file_history2";
			this.file_history2.Size = new System.Drawing.Size(104, 80);
			this.file_history2.TabIndex = 0;
			// 
			// MainForm
			// 
			this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
			this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
			this.ClientSize = new System.Drawing.Size(503, 339);
			this.Controls.Add(this.Level1_SplitContainer);
			this.Controls.Add(this.status_strip);
			this.Controls.Add(this.drive_toolbar);
			this.Controls.Add(this.tool_strip);
			this.Controls.Add(this.menu_strip);
			this.MainMenuStrip = this.menu_strip;
			this.Name = "MainForm";
			this.Text = "SCFiler2";
			this.FormClosing += new System.Windows.Forms.FormClosingEventHandler(this.MainForm_FormClosing);
			this.KeyDown += new System.Windows.Forms.KeyEventHandler(this.MainForm_KeyDown);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.menu_strip.ResumeLayout(false);
			this.menu_strip.PerformLayout();
			this.Level1_SplitContainer.Panel1.ResumeLayout(false);
			this.Level1_SplitContainer.Panel2.ResumeLayout(false);
			this.Level1_SplitContainer.ResumeLayout(false);
			this.Level2_Main_SplitContainer.Panel1.ResumeLayout(false);
			this.Level2_Main_SplitContainer.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.Panel1.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.Panel2.ResumeLayout(false);
			this.Level3_Listview_SplitContainer.ResumeLayout(false);
			this.Level3_History1_SplitContainer.Panel1.ResumeLayout(false);
			this.Level3_History1_SplitContainer.Panel2.ResumeLayout(false);
			this.Level3_History1_SplitContainer.ResumeLayout(false);
			this.Level3_History2_SplitContainer.Panel1.ResumeLayout(false);
			this.Level3_History2_SplitContainer.Panel2.ResumeLayout(false);
			this.Level3_History2_SplitContainer.ResumeLayout(false);
			this.ResumeLayout(false);
			this.PerformLayout();

		}

		#endregion

		private System.Windows.Forms.MenuStrip menu_strip;
		private System.Windows.Forms.ToolStrip tool_strip;
		private System.Windows.Forms.StatusStrip status_strip;
		private System.Windows.Forms.SplitContainer Level1_SplitContainer;
		private System.Windows.Forms.SplitContainer Level2_Main_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_Listview_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_History1_SplitContainer;
		private System.Windows.Forms.SplitContainer Level3_History2_SplitContainer;
		private FileView left_file_listview;
		private FileView right_file_listview;
		private System.Windows.Forms.ToolStrip drive_toolbar;
		private System.Windows.Forms.ToolStripMenuItem ファイルFToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem フォルダDToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem ツールTToolStripMenuItem;
		private System.Windows.Forms.ToolStripMenuItem 設定OToolStripMenuItem;
		private HistoryView folder_history;
		private HistoryView file_history1;
		private HistoryView file_history2;
	}
}
